wsipipe.preprocess.tissue\_detection package
============================================

.. automodule:: wsipipe.preprocess.tissue_detection
   :members:
   :undoc-members:
   :show-inheritance:

tissue\_detector module
------------------------------------------------------------

.. automodule:: wsipipe.preprocess.tissue_detection.tissue_detector
   :members:
   :undoc-members:
   :show-inheritance:

filters module
---------------------------------------------------

.. automodule:: wsipipe.preprocess.tissue_detection.filters
   :members:
   :undoc-members:
   :show-inheritance:

morphology\_transforms module
------------------------------------------------------------------

.. automodule:: wsipipe.preprocess.tissue_detection.morphology_transforms
   :members:
   :undoc-members:
   :show-inheritance:

visualise module
-----------------------------------------------------

.. automodule:: wsipipe.preprocess.tissue_detection.visualise
   :members:
   :undoc-members:
   :show-inheritance:

